curl -o config.json http://172.23.198.21:8909/getFile?fileName=config.json
curl -o generation_config.json http://172.23.198.21:8909/getFile?fileName=generation_config.json
curl -o model.safetensors.index.json http://172.23.198.21:8909/getFile?fileName=model.safetensors.index.json
curl -o special_tokens_map.json http://172.23.198.21:8909/getFile?fileName=special_tokens_map.json
curl -o tokenizer.json http://172.23.198.21:8909/getFile?fileName=tokenizer.json
curl -o tokenizer_config.json http://172.23.198.21:8909/getFile?fileName=tokenizer_config.json
curl -o model-00001-of-00004.safetensors http://172.23.198.21:8909/getFile?fileName=model-00001-of-00004.safetensors
curl -o model-00002-of-00004.safetensors http://172.23.198.21:8909/getFile?fileName=model-00002-of-00004.safetensors
curl -o model-00003-of-00004.safetensors http://172.23.198.21:8909/getFile?fileName=model-00003-of-00004.safetensors
curl -o model-00004-of-00004.safetensors http://172.23.198.21:8909/getFile?fileName=model-00004-of-00004.safetensors
